@@ -8,6 +8,7 @@
    Description :
 -------------------------------------------------
 """
+import imp
 import random
 import unittest
 
@@ -43,3 +44,25 @@ class TestUtils(unittest.TestCase):
             return a + b
 
         sleep_add(1, 2)
+
+    def test_multi_work(self):
+        @batch_process(work_num=2)
+        def add1(a):
+            return a+1
+
+        rs = add1(data=[1, 2, 3, 4, 5, 6, 7, 8, 9, 10])
+        print(rs)
+
+
+if __name__ == "__main__":
+    from time import sleep
+
+    @batch_process(work_num=3)
+    def add1(a, b=2):
+        # print(f"{a}+{b}")
+        sleep(1)
+        return a+b
+
+    rs = add1(data=[1, 2, 3, 4, 5, 6, 7, 8, 9, 10], b=3)
+    print(rs)
+    # print(list(rs))
